diff options
| author | KunoiSayami <[email protected]> | 2022-02-17 13:28:17 +0800 |
|---|---|---|
| committer | KunoiSayami <[email protected]> | 2022-02-17 13:28:17 +0800 |
| commit | e98fc6bf301bb3bf38aab4ccce51edc16953024b (patch) | |
| tree | 14982778788a6ce9e1268a0fe338c1f9a5e714ec /db | |
| parent | 1e4c8faa097c5423604e343bf20745f57c81f2a9 (diff) | |
Diffstat (limited to 'db')
| -rw-r--r-- | db/skiplist.cuh | 2 | ||||
| -rw-r--r-- | db/skiplist_test.cu | 6 |
2 files changed, 4 insertions, 4 deletions
diff --git a/db/skiplist.cuh b/db/skiplist.cuh index 3f7b7e9..2501af8 100644 --- a/db/skiplist.cuh +++ b/db/skiplist.cuh @@ -453,7 +453,7 @@ __device__ void SkipList<Key, Comparator>::Insert(const Key& key) { // NoBarrier_SetNext() suffices since we will add a barrier when // we publish a pointer to "x" in prev[i]. while (true) { - assert(prev[i]->key < key); + //assert(prev[i]->key < key); if (prev[i]->SetNextSafe(i, x)) break; //printf("failed\n"); diff --git a/db/skiplist_test.cu b/db/skiplist_test.cu index 06675cd..d73e433 100644 --- a/db/skiplist_test.cu +++ b/db/skiplist_test.cu @@ -397,14 +397,14 @@ TEST(SkipTest, TestLock) { cudaDeviceSynchronize(); } -constexpr size_t BLOCK_COUNT_X = 40; -constexpr size_t BLOCK_COUNT_Y = 256; +constexpr size_t BLOCK_COUNT_X = 8; +constexpr size_t BLOCK_COUNT_Y = 128; constexpr size_t TEST_STEP = 1; constexpr size_t SKIPLIST_TEST_SIZE = BLOCK_COUNT_X * BLOCK_COUNT_Y * TEST_STEP; __global__ void testParallel(SkipList<Key, Comparator> * skipList, Key * keys, CudaSpinLock * lock) { unsigned int start = blockIdx.x * blockDim.x + threadIdx.x; - printf("%u\t%d\t%d\t%d\n", start, blockIdx.x, blockDim.x, threadIdx.x); + //printf("%u\t%d\t%d\t%d\n", start, blockIdx.x, blockDim.x, threadIdx.x); //printf("%u\n", start); //lock->lock(); //printf("start insert: %u\n", start); |
